#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
-----------------File Info-----------------------
            Name: __about__.py
            Description: information about this package
            Author: GentleCP
            Email: me@gentlecp.com
            WebSite: https://blog.gentlecp.com
            Create Date: 2021/4/18 
-----------------End-----------------------------
"""

__name__ = 'corpwechatbot'
__description__ = 'python interface for corpwechat message sending'
__url__ = 'https://github.com/GentleCP/corpwechat-bot'
__version__= '0.6.0'
__author__ = 'GentleCP'
__author_email__ = 'me@gentlecp.com'
__license__ = 'GPL v3'